// Foundation by ZURB
// foundation.zurb.com
// Licensed under MIT Open Source
// toolbar styles

.toolbar {
	background: $oil;
	width: 100%;
	font-size: 0;
	display: inline-block;

	&.label-bottom .tab .tab-content {
		i, img { margin-bottom: 10px; }
	}

	&.label-right .tab .tab-content {
		i, img { margin-right: 10px; display: inline-block;}
		label { display: inline-block; }
	}

	&.vertical.label-right .tab .tab-content {
		text-align: left;
	}

	&.vertical {
		height: 100%;
		width: auto;

		.tab {
			width: auto;
			margin: auto;
			float: none;
		}
	}
	
	.tab {
		text-align: center;
		width: 25%;
		margin: 0 auto;
		display: block;
		padding: 20px;
		float: left;

		&:hover {
			background: rgba($white, 0.1);
		}
	}
}		
		
.toolbar .tab-content {
	font-size: 16px;
	text-align: center;

	label { color: $iron; }

	i {
		font-size: 30px;
		display: block;
		margin: 0 auto;
		color: $iron;
		vertical-align: middle;
	}

	img {
		width: 30px;
		height: 30px;
		display: block;
		margin: 0 auto;
	}
}